==> speech-analytic-testing_2.3.1_database.tar.gz: database/mssql/procedures/SaveProcess.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveProcess] (
	@VCC Varchar(50) = NULL,
	@Name Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@ClientId Varchar(50) = NULL,
	@Type VARCHAR(50),
	@Status Varchar(50) = NULL,
	@StartDate Datetime = NULL,
	@EndDate Datetime = NULL,
	@MinDurationTime Numeric(18, 2) = NULL,
	@MaxDurationTime Numeric(18, 2) = NULL,
	@Language VARCHAR(25) = NULL,
	@DictionaryId VARCHAR(50) = NULL,
	@Environment Varchar(50) = NULL,
	@QueryId Varchar(50) = NULL,
	@QueryDataId Varchar(50) = NULL,
	@QueryDataIdDate Datetime = NULL,
	@BatchScheduleId VARCHAR(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	
	UPDATE [Process]
	SET [Description] = @Description,
		[ClientId] = @ClientId,
		[Status] = @Status,
		[Type] = @Type,
		[StartDate] = @StartDate,
		[EndDate] = @EndDate,
		[MinDurationTime] = @MinDurationTime,
		[MaxDurationTime] = @MaxDurationTime,
		[Language] = @Language,
		[DictionaryId] = @DictionaryId,
		[Environment] = @Environment,
		[QueryId] = @QueryId,
		[QueryDataId] = @QueryDataId,
		[QueryDataIdDate] = @QueryDataIdDate,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE()
	WHERE [VCC] = @VCC
    AND [Name] = @Name

    IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [Process] (
			[VCC], [Name], [Description],
			[ClientId], [Status], [Type], [StartDate],
			[EndDate], [MinDurationTime], [MaxDurationTime], 
			[Language], [DictionaryId], [Environment], 
			[QueryId], [QueryDataId], [QueryDataIdDate],
			[BatchScheduleId], 
			[CreatedDate], [CreatedByUserId], [LastModifiedDate], 
			[LastModifiedByUserId], [TimeStamp]
			)
		VALUES (
			@VCC, @Name, @Description,
			@ClientId, @Status, @Type, @StartDate,
			@EndDate, @MinDurationTime, @MaxDurationTime, 
			@Language, @DictionaryId, @Environment, 
			@QueryId, @QueryDataId, @QueryDataIdDate, 
			@BatchScheduleId,
			@CreatedDate, @CreatedByUserId, @LastModifiedDate, 
			@LastModifiedByUserId, GETUTCDATE()
		)
	END
    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_2.6.0_database.tar.gz: database/mssql/procedures/SaveProcess.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveProcess] (
	@VCC Varchar(50) = NULL,
	@Name Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@ClientId Varchar(50) = NULL,
	@Type VARCHAR(50),
	@Status Varchar(50) = NULL,
	@StartDate Datetime = NULL,
	@EndDate Datetime = NULL,
	@MinDurationTime Numeric(18, 2) = NULL,
	@MaxDurationTime Numeric(18, 2) = NULL,
	@Language VARCHAR(25) = NULL,
	@DictionaryId VARCHAR(50) = NULL,
	@Environment Varchar(50) = NULL,
	@QueryId Varchar(50) = NULL,
	@QueryDataId Varchar(50) = NULL,
	@QueryDataIdDate Datetime = NULL,
	@BatchScheduleId VARCHAR(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,
	@Retranscription BIT = 0,
	@Diarization BIT = 0,
	@ChannelChange BIT = 0
	)
AS
BEGIN
	SET NOCOUNT ON
	
	UPDATE [Process]
	SET [Description] = @Description,
		[ClientId] = @ClientId,
		[Status] = @Status,
		[Type] = @Type,
		[StartDate] = @StartDate,
		[EndDate] = @EndDate,
		[MinDurationTime] = @MinDurationTime,
		[MaxDurationTime] = @MaxDurationTime,
		[Language] = @Language,
		[DictionaryId] = @DictionaryId,
		[Environment] = @Environment,
		[QueryId] = @QueryId,
		[QueryDataId] = @QueryDataId,
		[QueryDataIdDate] = @QueryDataIdDate,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE()
		
	WHERE [VCC] = @VCC
    AND [Name] = @Name

    IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [Process] (
			[VCC], [Name], [Description],
			[ClientId], [Status], [Type], [StartDate],
			[EndDate], [MinDurationTime], [MaxDurationTime], 
			[Language], [DictionaryId], [Environment], 
			[QueryId], [QueryDataId], [QueryDataIdDate],
			[BatchScheduleId], 
			[CreatedDate], [CreatedByUserId], [LastModifiedDate], 
			[LastModifiedByUserId], [TimeStamp], [Retranscription], [Diarization], [ChannelChange]
			)
		VALUES (
			@VCC, @Name, @Description,
			@ClientId, @Status, @Type, @StartDate,
			@EndDate, @MinDurationTime, @MaxDurationTime, 
			@Language, @DictionaryId, @Environment, 
			@QueryId, @QueryDataId, @QueryDataIdDate, 
			@BatchScheduleId,
			@CreatedDate, @CreatedByUserId, @LastModifiedDate, 
			@LastModifiedByUserId, GETUTCDATE(), @Retranscription, @Diarization, @ChannelChange
		)
	END
	--En caso de retranscripcion regresar todos los audios a su estado inicial 
	IF @Retranscription = 1
	BEGIN
	  UPDATE A
	  SET A.[IsCancel] = 1,
	  A.[IsTranscribed] = null,
	  A.[init] = null,
	  A.[IsDiariced] = null,
	  A.[ChannelsChanged] = null
	  FROM Audio A inner join ProcessAudio PA on A.id = PA.AudioId
	  WHERE 
	  PA.[VCC] = @VCC AND
	  PA.[ProcessId] = @Name 
	  
	END

    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
